@@ -13,9 +13,10 @@ import urllib
 import gio
 import inspect
 PATH = "/apps/digghomewidget"
-CATGR = "/apps/digghomewidget/selected_category"
+CATGR = "/apps/digghomewidget/selected_category_int"
 NUM = "/apps/digghomewidget/number_of_stories"
 THMB = "/apps/digghomewidget/load_thumbnails"
+FIRST = "/apps/digghomewidget/first_run"
 class diggItem:
     def __init__(self, title, href, topic, diggs):
         self.title = title
@@ -35,7 +36,7 @@ class diggLoader:
             doc = xmlparser.parseString(self.stream.read_finish(result).read())
         except Exception, e:
             doc = None
-            print "Can't connect to Digg.com"
+            print "Can't connect to Digg.com", e
             self.callback(list=None)
         if doc != None:
             stories = doc.getElementsByTagName("story")
@@ -178,7 +179,7 @@ class CustomButton(hildon.Button):
         img = gtk.Image()
         img.set_from_file(self.icon)
         imgrect = img.get_allocation()
-        self.context.set_source_pixbuf(img.get_pixbuf(), rect.x+60, rect.y+1)
+        self.context.set_source_pixbuf(img.get_pixbuf(), rect.x+(event.area.width/2-15), rect.y+1)
         self.context.paint()
         return self.retval
 
@@ -248,27 +249,49 @@ class DiggHomePlugin(hildondesktop.HomePluginItem):
         self.connect("show-settings", self.show_settings)
         self.loader = diggLoader(self.update) 
         self.client = gconf.client_get_default()
-        temp = self.client.get_string(CATGR)
-        if temp != None and temp !="":
-            self.category = temp 
-        else:
-            self.category = ""
-        temp = self.client.get_int(NUM)
-        if temp == 0:
+        try:
+            temp_first = self.client.get_bool(FIRST)
+            temp_cat = self.client.get_int(CATGR)
+            temp_num = self.client.get_int(NUM)
+            temp_check = self.client.get_bool(THMB)
+        except:
+            temp_first = False
+            
+        self.categories = []
+        self.categories.append("")
+        self.categories.append("Technology")
+        self.categories.append("World&Business")
+        self.categories.append("Entertainment")
+        self.categories.append("Gaming")
+        self.categories.append("Science")
+        self.categories.append("Sports")
+        self.categories.append("Lifestyle")
+        self.categories.append("Offbeat")
+        if temp_first == False:
             self.count = 2
             self.checkbox_active = True 
             self.loader.load_thumbnails = True 
-        if temp != None:
-            self.count = temp 
+            self.category = 0
+            self.client.set_bool(THMB, self.loader.load_thumbnails)
+            self.client.set_int(NUM, self.count)
+            self.client.set_int(CATGR, self.category)
+            self.client.set_bool(FIRST, True)
         else:
-            self.count = 2
-        temp = self.client.get_bool(THMB)
-        if temp != None:
-            self.checkbox_active = temp 
-            self.loader.load_thumbnails = temp 
-        else:
-            self.checkbox_active = True 
-            self.loader.load_thumbnails = True 
+            if temp_cat != None and temp_cat !="" and temp_cat != 0:
+                self.category = temp_cat 
+            else:
+                self.category = 0
+            if temp_num != None and temp_num != 0:
+                self.count = temp_num 
+            else:
+                self.count = 2
+            if temp_check != None:
+                self.checkbox_active = temp_check 
+                self.loader.load_thumbnails = temp_check 
+            else:
+                self.checkbox_active = True 
+                self.loader.load_thumbnails = True 
+        print "CAT:", self.category
         self.hotness = "Top"
         container = gtk.Alignment(0.0,0.0,1.0,1.0)
         container.set_padding(2,1,0,0)
@@ -279,7 +302,7 @@ class DiggHomePlugin(hildondesktop.HomePluginItem):
         #list = diggapi.get_toplist(container=self.category,count=self.count)
         mainVBox = gtk.VBox(spacing=1)
         mainVBox.add(logo)
-        titletext = self.category
+        titletext = self.categories[self.category]
         if titletext == "":
             titletext = "All"
         #titletext = titletext +" > " + self.hotness# + " Updated 21.10.2009"
@@ -294,12 +317,9 @@ class DiggHomePlugin(hildondesktop.HomePluginItem):
         hbox = gtk.HBox(spacing=0)
         update = CustomButton("/opt/digghomewidget/update.png")
         update.connect("clicked", self.update_button)
+        settings = CustomButton("/opt/digghomewidget/settings.png")
+        settings.connect("clicked", self.change_topic)
         hbox.add(update)
-        settings = CustomPickerButton("/opt/digghomewidget/settings.png")
-        settings.set_title("Pick a category")
-        self.selector = self.show_selector()
-        settings.set_selector(self.selector)
-        settings.connect("value-changed", self.category_changed)
         hbox.add(settings)
         mainVBox.add(self.vbox)
         mainVBox.add(hbox)
@@ -307,8 +327,8 @@ class DiggHomePlugin(hildondesktop.HomePluginItem):
         container.show_all()
         self.add(container)
         self.connect("notify::is-on-current-desktop", self.on_desktop)
-#        self.set_size_request(300, -1)
-        self.loader.get_toplist(container=self.category,count=self.count)
+        self.set_size_request(300, 150)
+        self.loader.get_toplist(container=self.categories[self.category],count=self.count)
 #        gtk.Settings.gtk-enable-animations = False
 
     def on_desktop(self, widget, data):
@@ -318,7 +338,47 @@ class DiggHomePlugin(hildondesktop.HomePluginItem):
     def update_button(self, widget):
         self.row.title = "Updating..."
         self.row.queue_draw()
-        self.loader.get_toplist(container=self.category,count=self.count)
+        self.loader.get_toplist(container=self.categories[self.category],count=self.count)
+
+    def change_topic(self, widget):
+        dialog = gtk.Dialog()
+        dialog.set_title("Settings")
+        selector = hildon.TouchSelector(text = True) 
+        selector.connect("changed", self.selection_changed)
+        selector.append_text("All")
+        selector.append_text("Technology")
+        selector.append_text("World&Business")
+        selector.append_text("Entertainment")
+        selector.append_text("Gaming")
+        selector.append_text("Science")
+        selector.append_text("Sports")
+        selector.append_text("Lifestyle")
+        selector.append_text("Offbeat")
+        selector.set_column_selection_mode(hildon.TOUCH_SELECTOR_SELECTION_MODE_SINGLE)
+        categoryPicker = hildon.PickerButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
+        categoryPicker.set_alignment(0.0, 0.5, 1.0, 1.0)
+        categoryPicker.set_title("Category")
+        categoryPicker.set_selector(selector)
+        categoryPicker.set_active(self.category)
+        thumbn_checkbox = hildon.CheckButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT)
+        thumbn_checkbox.set_label("Load thumbnails")
+        thumbn_checkbox.set_active(self.loader.load_thumbnails)
+        thumbn_checkbox.connect("toggled", self.checkbox_toggle)
+        dialog.vbox.add(thumbn_checkbox)
+        dialog.vbox.add(categoryPicker)
+        dialog.add_button("Save", gtk.RESPONSE_OK)
+        dialog.show_all()
+        response = dialog.run()
+        dialog.destroy()
+        if response == gtk.RESPONSE_OK:
+            self.loader.load_thumbnails = self.checkbox_active 
+            self.client.set_bool(THMB, self.loader.load_thumbnails)
+            self.category = categoryPicker.get_active() 
+            self.client.set_string(CATGR, self.categories[self.category])
+            self.update_button(self)
+        
+    def pickerValueChanged(self, button, user_data=None):
+        self.pickerValue = button.get_value()
         
 
     def update(self, list):
@@ -332,8 +392,8 @@ class DiggHomePlugin(hildondesktop.HomePluginItem):
                     button = DiggItemWidget(item)
                     self.vbox.pack_start(button, False)
             self.show_all()
-            self.client.set_string(CATGR, self.category)
-            title = self.category
+            self.client.set_string(CATGR, self.categories[self.category])
+            title = self.categories[self.category]
             title = title.replace("_", "&")
             if title == "":
                 title = "All"
@@ -382,6 +442,7 @@ class DiggHomePlugin(hildondesktop.HomePluginItem):
         dialog = gtk.Dialog()
         dialog.set_transient_for(self)
         dialog.set_title("Settings")
+#        settings.connect("value-changed", self.category_changed)
         thumbn_checkbox = hildon.CheckButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT)
         thumbn_checkbox.set_label("Load thumbnails")
         dialog.add_button("Save", gtk.RESPONSE_OK)
@@ -398,7 +459,7 @@ class DiggHomePlugin(hildondesktop.HomePluginItem):
         thumbn_checkbox.set_active(self.loader.load_thumbnails)
         thumbn_checkbox.connect("toggled", self.checkbox_toggle)
         dialog.vbox.add(num_itemsPicker)
-        dialog.vbox.add(thumbn_checkbox)
+#        dialog.vbox.add(thumbn_checkbox)
         dialog.show_all()
         response = dialog.run()
         dialog.destroy()
@@ -423,11 +484,3 @@ class DiggHomePlugin(hildondesktop.HomePluginItem):
 
 hd_plugin_type = DiggHomePlugin
 
-
-if __name__ == "__main__":
-    import gobject
-    gobject.type_register(hd_plugin_type)
-    obj = gobject.new(hd_plugin_type, plugin_id="plugin_id")
-    obj.show_all()
-    gtk.main()
-
